from ..Base import *
from ..Proxy import *
from ..AcadObject import *

class AcadPopupMenu(AppObject):
    def __init__(self, obj) -> None: ...
    Application: AcadApplication
    Count: int
    Name: str
    NameNoMnemonic: str
    OnMenuBar: bool
    Parent: AppObject
    ShortcutMenu: bool
    TagString: str
    def AddMenuItem(self, Index: int | str, Label: str, Macro: str) -> AcadPopupMenuItem: ...
    def AddSeparator(self, Index: int | str) -> AcadPopupMenuItem: ...
    def AddSubMenu(self, Index: int | str, Label: str) -> AcadPopupMenu: ...
    def InsertInMenuBar(self, Index: int | str) -> None: ...
    def Item(self, Index: int | str) -> AcadPopupMenu: ...
    def RemoveMenuFromMenuBar(self, Index: int) -> None: ...
