from ..Base import *
from ..Proxy import *
from ..AcadObject import *

class AcadSectionManager(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def GetLiveSection(self) -> AcadSection: ...
    def GetUniqueSectionName(self) -> str: ...
