from simpleautocad import *
from colorama import Back as Back, Style as Style

def prop_test(obj, name: str, assertion: type, access: AccessMode, write_value=None): ...
def method_test(obj, name: str, ret_type=..., **kwargs): ...
def test_AcadApplication(acad_app: AcadApplication): ...
def test_AcadDocument(acad_active_document: AcadDocument): ...
def test_transform(acad_app: AutoCAD, acad_active_document: AcadDocument, acad_model_space: AcadModelSpace): ...
def test_create(object_AcadCircle, object_Acad3DFace, object_AcadPolygonMesh, object_Acad3DPolyline, object_AddArc, object_AcadAttribute, object_AddMInsertBlock) -> None: ...
