from ..Base import *
from ..AcadObject import *
from ..Proxy import *
from .AcadState import AcadState as AcadState

class AcadApplication(Application, AppObject):
    __app_name__: str
    ActiveDocument: AcadDocument
    Application: AcadApplication
    Caption: str
    Documents: AcadDocuments
    FullName: str
    Height: float
    HWND: int
    LocaleId: int
    MenuBar: AcadMenuBar
    MenuGroups: AcadMenuGroups
    Name: str
    Path: str
    Preferences: AcadPreferences
    VBE: AppObject
    Version: str
    Visible: bool
    Width: float
    WindowLeft: int
    WindowState: int
    WindowTop: int
    def StatusID(self, VportObj: AcadViewport) -> bool: ...
    def Eval(self, Expression: str) -> None: ...
    def GetAcadState(self) -> AcadState: ...
    def GetInterfaceObject(self, ProgID: str) -> AppObject: ...
    def ListARX(self) -> vStringArray: ...
    def LoadARX(self, Name) -> None: ...
    def LoadDVB(self, Name) -> None: ...
    def Quit(self) -> None: ...
    def RunMacro(self, MacroPath: str) -> None: ...
    def UnloadARX(self, Name: str) -> None: ...
    def UnloadDVB(self, Name: str) -> None: ...
    def Update(self) -> None: ...
    def ZoomAll(self) -> None: ...
    def ZoomCenter(self, Center: PyGePoint3d, Magnify: float) -> None: ...
    def ZoomExtents(self) -> None: ...
    def ZoomPickWindow(self) -> None: ...
    def ZoomPrevious(self) -> None: ...
    def ZoomScaled(self, Scale: float, ScaleType: AcZoomScaleType) -> None: ...
    def ZoomWindow(self, LowerLeft: PyGePoint3d, UpperRight: PyGePoint3d) -> None: ...
