from __future__ import annotations
from ..Base import *
from ..Proxy import *



class AcadSectionTypeSettings(AppObject):
    def __init__(self, obj) -> None: super().__init__(obj)
    
    BackgroundLinesColor: AcadAcCmColor = proxy_property('AcadAcCmColor','BackgroundLinesColor',AccessMode.ReadWrite)
    BackgroundLinesHiddenLine: bool = proxy_property(bool,'BackgroundLinesHiddenLine',AccessMode.ReadWrite)
    BackgroundLinesLayer: str = proxy_property(str,'BackgroundLinesLayer',AccessMode.ReadWrite)
    BackgroundLinesLinetypeScale: float = proxy_property(float,'BackgroundLinesLinetypeScale',AccessMode.ReadWrite)
    BackgroundLinesLineweight: AcLineWeight = proxy_property('AcLineWeight','BackgroundLinesLineweight',AccessMode.ReadWrite)
    BackgroundLinesPlotStyleName: str = proxy_property(str,'BackgroundLinesPlotStyleName',AccessMode.ReadWrite)
    BackgroundLinesVisible: bool = proxy_property(bool,'BackgroundLinesVisible',AccessMode.ReadWrite)
    CurveTangencyLinesColor: AcadAcCmColor = proxy_property('AcadAcCmColor','CurveTangencyLinesColor',AccessMode.ReadWrite)
    CurveTangencyLinesLayer: str = proxy_property(str,'CurveTangencyLinesColor',AccessMode.ReadWrite)
    CurveTangencyLinesLinetype: str = proxy_property(str,'CurveTangencyLinesLinetype',AccessMode.ReadWrite)
    CurveTangencyLinesLinetypeScale: float = proxy_property(float,'CurveTangencyLinesLinetypeScale',AccessMode.ReadWrite)
    CurveTangencyLinesLineweight: AcLineWeight = proxy_property('AcLineWeight','CurveTangencyLinesLineweight',AccessMode.ReadWrite)
    CurveTangencyLinesPlotStyleName: str = proxy_property(str,'CurveTangencyLinesPlotStyleName',AccessMode.ReadWrite)
    CurveTangencyLinesVisible: bool = proxy_property(bool,'CurveTangencyLinesVisible',AccessMode.ReadWrite)
    DestinationBlock: Variant = proxy_property('Variant','DestinationBlock',AccessMode.ReadWrite)
    DestinationFile: str = proxy_property(str,'DestinationFile',AccessMode.ReadWrite)
    ForegroundLinesColor: AcadAcCmColor = proxy_property('AcadAcCmColor','ForegroundLinesColor',AccessMode.ReadWrite)
    ForegroundLinesEdgeTransparency: int = proxy_property(int,'ForegroundLinesEdgeTransparency',AccessMode.ReadWrite)
    ForegroundLinesFaceTransparency: int = proxy_property(int,'ForegroundLinesFaceTransparency',AccessMode.ReadWrite)
    ForegroundLinesHiddenLine: bool = proxy_property(bool,'ForegroundLinesHiddenLine',AccessMode.ReadWrite)
    ForegroundLinesLayer: str = proxy_property(str,'ForegroundLinesLayer',AccessMode.ReadWrite)
    ForegroundLinesLinetype: str = proxy_property(str,'ForegroundLinesLinetype',AccessMode.ReadWrite)
    ForegroundLinesLinetypeScale: float = proxy_property(float,'ForegroundLinesLinetypeScale',AccessMode.ReadWrite)
    ForegroundLinesLineweight: AcLineWeight = proxy_property('AcLineWeight','ForegroundLinesLineweight',AccessMode.ReadWrite)
    ForegroundLinesPlotStyleName: str = proxy_property(str,'ForegroundLinesPlotStyleName',AccessMode.ReadWrite)
    ForegroundLinesVisible: bool = proxy_property(bool,'ForegroundLinesVisible',AccessMode.ReadWrite)
    GenerationOptions: AcSectionGeneration = proxy_property('AcSectionGeneration','GenerationOptions',AccessMode.ReadWrite)
    IntersectionBoundaryColor: AcadAcCmColor = proxy_property('AcadAcCmColor','IntersectionBoundaryColor',AccessMode.ReadWrite)
    IntersectionBoundaryDivisionLines: bool = proxy_property(bool,'IntersectionBoundaryDivisionLines',AccessMode.ReadWrite)
    IntersectionBoundaryLayer: str = proxy_property(str,'IntersectionBoundaryLayer',AccessMode.ReadWrite)
    IntersectionBoundaryLinetype: str = proxy_property(str,'IntersectionBoundaryLinetype',AccessMode.ReadWrite)
    IntersectionBoundaryLinetypeScale: float = proxy_property(float,'IntersectionBoundaryLinetypeScale',AccessMode.ReadWrite)
    IntersectionBoundaryLineweight: AcLineWeight = proxy_property('AcLineWeight','IntersectionBoundaryLineweight',AccessMode.ReadWrite)
    IntersectionBoundaryPlotStyleName: str = proxy_property(str,'IntersectionBoundaryPlotStyleName',AccessMode.ReadWrite)
    IntersectionBoundaryVisible: bool = proxy_property(bool,'IntersectionBoundaryVisible',AccessMode.ReadWrite)
    IntersectionFillColor: AcadAcCmColor = proxy_property('AcadAcCmColor','IntersectionFillColor',AccessMode.ReadWrite)
    IntersectionFillFaceTransparency: int = proxy_property(int,'IntersectionFillFaceTransparency',AccessMode.ReadWrite)
    IntersectionFillHatchAngle: float = proxy_property(float,'IntersectionFillHatchAngle',AccessMode.ReadWrite)
    IntersectionFillHatchPatternName: str = proxy_property(str,'IntersectionFillHatchPatternName',AccessMode.ReadWrite)
    IntersectionFillHatchPatternType: AcPatternType = proxy_property(AcPatternType,'IntersectionFillHatchPatternType',AccessMode.ReadWrite)
    IntersectionFillHatchScale: float = proxy_property(float,'IntersectionFillHatchScale',AccessMode.ReadWrite)
    IntersectionFillHatchSpacing: float = proxy_property(float,'IntersectionFillHatchSpacing',AccessMode.ReadWrite)
    IntersectionFillLayer: str = proxy_property(str,'IntersectionFillLayer',AccessMode.ReadWrite)
    IntersectionFillLinetype: str = proxy_property(str,'IntersectionFillLinetype',AccessMode.ReadWrite)
    IntersectionFillLinetypeScale: float = proxy_property(float,'IntersectionFillLinetypeScale',AccessMode.ReadWrite)
    IntersectionFillLineweight: AcLineWeight = proxy_property('AcLineWeight','IntersectionFillLineweight',AccessMode.ReadWrite)
    IntersectionFillPlotStyleName: str = proxy_property(str,'IntersectionFillPlotStyleName',AccessMode.ReadWrite)
    IntersectionFillVisible: bool = proxy_property(bool,'IntersectionFillVisible',AccessMode.ReadWrite)
    SourceObjects: Variant = proxy_property('Variant','SourceObjects',AccessMode.ReadWrite)
