from ..Base import *
from ..Proxy import *
from ..AcadObject import *

class AcadSelectionSet(AppObject):
    def __init__(self, obj) -> None: ...
    Application: AcadApplication
    Count: int
    Name: str
    def AddItems(self, Items: vObjectArray) -> None: ...
    def Clear(self) -> None: ...
    def Delete(self) -> None: ...
    def Erase(self) -> None: ...
    def Highlight(self, HighlightFlag: bool) -> None: ...
    def Item(self, Index: int | str) -> AcadObject: ...
    def RemoveItems(self, Objects: vObjectArray) -> None: ...
    def Select(self, Mode: AcSelect, Point1: PyGePoint3d = None, Point2: PyGePoint3d = None, FilterType: Variant[AdeskDxfCode] = None, FilterData: Variant = None) -> None: ...
    def SelectAtPoint(self, Point: PyGePoint3d, FilterType: Variant[AdeskDxfCode] = None, FilterData: Variant = None) -> None: ...
    def SelectByPolygon(self, Mode: AcSelect, PointsList: PyGePoint3dArray, FilterType: Variant[AdeskDxfCode] = None, FilterData: Variant = None) -> None: ...
    def SelectOnScreen(self, FilterType: Variant[AdeskDxfCode] = None, FilterData: Variant = None) -> None: ...
    def Update(self) -> None: ...
