from .Autocad.AcadEntity import *
from .Autocad.AcadObject import *
from .Autocad.Entities import *
from .Autocad.Objects import *
from .Types import *
from .Autocad.Proxy import *
from abc import ABC

class AutoCAD(AcadApplication):
    def __init__(self) -> None: ...
    def uGetAcadAcCmColor(self) -> AcadAcCmColor: ...
    def uGetAcadLayerStateManager(self) -> AcadLayerStateManager: ...
    def uGetAcadSecurityParams(self) -> AcadSecurityParams: ...
    def uSetXData(obj: AcadObject, xdm: XDataManager) -> None: ...
    def uGetObjectType(self, obj: AcadObject) -> type | None: ...

class BlockReference(ABC): ...