from ..Base import *
from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property

class AcadPreferencesProfiles(AppObject):
    def __init__(self, obj) -> None: ...
    ActiveProfile: str
    Application: AcadApplication
    def CopyProfile(self, oldProfileName: str, newProfileName: str) -> None: ...
    def DeleteProfile(self, ProfileName: str) -> None: ...
    def ExportProfile(self, Profile: str, RegFile: str) -> None: ...
    def GetAllProfileNames(self) -> tuple[str]: ...
    def ImportProfile(self, Profile: str, RegFile: str, IncludePathInfo: bool) -> None: ...
    def RenameProfile(self, origProfileName: str, newProfileName: str) -> None: ...
    def ResetProfile(self, Profile: str) -> None: ...
