from ..Base import *
from ..Proxy import *
from ..AcadObject import *

class AcadLayers(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str) -> AcadLayer: ...
    def Item(self, Index: int | str) -> AcadLayer: ...
    def __iter__(self): ...
