from ..Base import *
from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property

class AcadLayerStateManager(AppObject):
    def __init__(self, obj) -> None: ...
    def Mask(self, Name: str) -> AcLayerStateMask | int: ...
    def Delete(self, Name: str) -> None: ...
    def Export(self, Name: str, FileName: str) -> None: ...
    def Import(self, FileName: str) -> None: ...
    def Rename(self, OldName: str, NewName: str) -> None: ...
    def Restore(self, Name: str) -> None: ...
    def Save(self, Name: str, Mask: AcLayerStateMask | int) -> None: ...
    def SetDatabase(self, Database: AcadDatabase) -> None: ...
