from ..Base import *
from ..Proxy import *
from ..AcadObject import *
from .AcadPlotConfiguration import *

class AcadPlotConfigurations(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str, ModelType: bool = None) -> AcadPlotConfiguration: ...
    def Item(self, Index: int | str) -> AcadPlotConfiguration: ...
    def __iter__(self): ...
