from ..Base import *
from ..Proxy import *
from ..AcadObject import *

class AcadPlot(AppObject):
    def __init__(self, obj) -> None: ...
    Application: AcadApplication
    BatchPlotProgress: bool
    NumberOfCopies: int
    QuietErrorMode: bool
    def DisplayPlotPreview(self, Preview: AcPreviewMode) -> None: ...
    def PlotToDevice(self, plotConfig: str = '') -> bool: ...
    def PlotToFile(self, plotFile: str, plotConfig: str = '') -> bool: ...
    def SetLayoutsToPlot(self, layoutList: vStringArray) -> None: ...
    def StartBatchMode(self, entryCount: int) -> None: ...
