from ..Base import *
from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property

class AcadLineTypes(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str) -> AcadLineType: ...
    def Item(self, Index: int | str) -> AcadLineType: ...
    def Load(self, LineTypeName: str, FileName: str) -> None: ...
    def __iter__(self): ...
