from ..Proxy import *
from ..AcadObject import AcadObject as AcadObject
from .AcadXRecord import AcadXRecord as AcadXRecord

class AcadDictionary(AcadObject):
    def __init__(self, obj) -> None: ...
    Name: str
    Count: int
    def AddObject(self, Keyword: str, ObjectName: str) -> AcadObject: ...
    def AddXRecord(self, Keyword: str) -> AcadXRecord: ...
    def GetName(self, Object: AppObject) -> str: ...
    def GetObject(self, Name: str) -> AcadObject: ...
    def Item(self, Index: int | str) -> AcadObject: ...
    def Remove(self, Name: str) -> AcadObject: ...
    def Rename(self, OldName: str, NewName: str) -> None: ...
    def Replace(self, Name: str, NewObject: AppObject) -> None: ...
