from ..Base import *
from ..Proxy import *
from ..AcadEntity import AcadEntity as AcadEntity

class AcadPolyline(AcadEntity):
    def __init__(self, obj) -> None: ...
    Area: float
    Closed: bool
    ConstantWidth: float
    Coordinates: PyGePoint3dArray
    Elevation: float
    Length: float
    LinetypeGeneration: bool
    Normal: PyGeVector3d
    Thickness: float
    Type: AcPolylineType
    def Coordinate(self, Index: int) -> PyGePoint3d: ...
    def Copy(self) -> AcadPolyline: ...
    def AppendVertex(self, Point: PyGePoint3d) -> None: ...
    def Explode(self) -> vObjectArray: ...
    def GetBulge(self, Index: int) -> float: ...
    def GetWidth(self, Index: int) -> vDoubleArray: ...
    def Offset(self, Distance: float) -> vObjectArray: ...
    def SetBulge(self, Index: int, Value: float) -> None: ...
    def SetWidth(self, SegmentIndex: int, StartWidth: float, EndWidth: float) -> None: ...
