from ..Base import *
from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property
from .AcadViewport import AcadViewport as AcadViewport

class AcadViewports(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str) -> AcadViewport: ...
    def DeleteConfiguration(self, Name: str) -> None: ...
    def Item(self, Index: int | str) -> AcadViewport: ...
    def __iter__(self): ...
