from ..Base import *
from ..Proxy import *
from ..AcadObject import *
from ..AcadEntity import *

class AcadSortentsTable(AcadObject):
    def __init__(self, obj) -> None: ...
    def Block(self) -> AcadBlock: ...
    def GetFullDrawOrder(self, honorSortentsSysvar: bool) -> vObjectArray: ...
    def GetRelativeDrawOrder(self, honorSortentsSysvar: bool) -> vObjectArray: ...
    def MoveAbove(self, Target: AcadEntity) -> vObjectArray: ...
    def MoveBelow(self, Target: AcadEntity) -> vObjectArray: ...
    def MoveToBottom(self, Objects: vObjectArray) -> None: ...
    def MoveToTop(self, Objects: vObjectArray) -> None: ...
    def SetRelativeDrawOrder(self, Objects: vObjectArray) -> None: ...
    def SwapOrder(self, Object1: AcadEntity, Object2: AcadEntity) -> None: ...
