from ..Base import *
from ..Proxy import *
from ..AcadEntity import AcadEntity as AcadEntity

class Acad3DFace(AcadEntity):
    def __init__(self, obj) -> None: ...
    Coordinates: PyGePoint3dArray
    VisibilityEdge1: bool
    VisibilityEdge2: bool
    VisibilityEdge3: bool
    VisibilityEdge4: bool
    def Coordinate(self, Index: int) -> PyGePoint3d: ...
    def Copy(self) -> Acad3DFace: ...
    def GetInvisibleEdge(self, Index: int) -> bool: ...
    def SetInvisibleEdge(self, Index: int, State: bool) -> None: ...
