from ..Base import *
from ..Proxy import *
from .AcadPopupMenu import *

class AcadPopupMenus(AppObject):
    def __init__(self, obj) -> None: ...
    Application: AcadApplication
    Count: int
    Parent: AppObject
    def Add(self, Name: str) -> AcadPopupMenu: ...
    def InsertMenuInMenuBar(self, MenuName: str, Index: int) -> None: ...
    def Item(self, Index: int) -> AcadPopupMenu: ...
    def RemoveMenuFromMenuBar(self, Index: int) -> None: ...
    def __iter__(self): ...
