from ..Base import *
from ..Proxy import *
from ..AcadObject import *
from .AcadHyperlink import *

class AcadHyperlinks(AppObjectCollection):
    def __init__(self, obj) -> None: ...
    Application: AcadApplication
    Count: int
    def Add(self, Name: str, Description: str = '', NamedLocation: str = '') -> AcadHyperlink: ...
    def Item(self, Index: int | str) -> AcadHyperlink: ...
    def __iter__(self): ...
