from ..AcadObject import *
from .AcadRegisteredApplication import AcadRegisteredApplication as AcadRegisteredApplication

class AcadRegisteredApplications(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str) -> AcadRegisteredApplication: ...
    def Item(self, Index: int) -> AcadRegisteredApplication: ...
    def __iter__(self): ...
