from ..Base import *
from ..Proxy import *
from ..AcadObject import *
from .AcadUCS import AcadUCS as AcadUCS

class AcadUCSs(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Origin: PyGePoint3d, XAxisPoint: PyGePoint3d, YAxisPoint: PyGePoint3d, Name: str) -> AcadUCS: ...
    def Item(self, Index: int) -> AcadUCS: ...
    def __iter__(self): ...
