from ..Base import *
from ..AcadObject import *
from .AcadTextStyle import *

class AcadTextStyles(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str = None) -> AcadTextStyle: ...
    def Item(self, Index: int) -> AcadTextStyle: ...
    def __iter__(self): ...
