from ..Base import *
from ..AcadObject import *
from ..Proxy import *
from .AcadDocument import AcadDocument as AcadDocument

class AcadDocuments(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    Application: AcadApplication
    Count: int
    def Add(self, Name: str = '') -> AcadDocument: ...
    def Close(self) -> None: ...
    def Item(self, Index: int) -> AcadDocument: ...
    def Open(self, Name: str, ReadOnly: bool = False, Password: Variant = ...) -> AcadDocument: ...
    def __iter__(self): ...
