from ..Base import *
from ..Proxy import *
from .AcadRasterImage import AcadRasterImage as AcadRasterImage

class AcadWipeout(AcadRasterImage):
    def __init__(self, obj) -> None: ...
    def Copy(self) -> AcadWipeout: ...
