from ..Base import *
from ..Proxy import *
from ..AcadEntity import AcadEntity as AcadEntity

class Acad3DPolyline(AcadEntity):
    def __init__(self, obj) -> None: ...
    Closed: bool
    Coordinates: PyGePoint3dArray
    Length: float
    Type: Ac3DPolylineType
    def Coordinate(self, Index: int) -> PyGePoint3d: ...
    def Copy(self) -> Acad3DPolyline: ...
    def AppendVertex(self, Point: PyGePoint3d) -> None: ...
    def Explode(self) -> vObjectArray: ...
