from ..Base import *
from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property

class AcadGroups(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, Name: str) -> AcadGroup: ...
    def Item(self, Index: int | str) -> AcadGroup: ...
    def __iter__(self): ...
