from ..Base import *
from ..Proxy import *
from ..AcadEntity import AcadEntity as AcadEntity

class AcadTable(AcadEntity):
    def __init__(self, obj) -> None: ...
    AllowManualHeights: bool
    AllowManualPositions: bool
    BreaksEnabled: bool
    BreakSpacing: float
    Columns: int
    ColumnWidth: float
    Direction: PyGeVector3d
    EnableBreak: bool
    FlowDirection: AcTableDirection
    HasSubSelection: bool
    HeaderSuppressed: bool
    Height: float
    HorzCellMargin: float
    InsertionPoint: PyGePoint3d
    MinimumTableHeight: float
    MinimumTableWidth: float
    RegenerateTableSuppressed: bool
    RepeatBottomLabels: bool
    RowHeight: float
    Rows: int
    StyleName: str
    TableBreakFlowDirection: AcTableFlowDirection
    TableBreakHeight: float
    TableStyleOverrides: AcTableStyleOverrides
    TitleSuppressed: bool
    VertCellMargin: float
    Width: float
    def ClearSubSelection(self) -> None: ...
    def ClearTableStyleOverrides(self, flag: int) -> None: ...
    def Copy(self, flag: int) -> AcadTable: ...
    def CreateContent(self, nRow: int, nCol: int, nIndex: int) -> int: ...
    def DeleteCellContent(self, row: int, col: int) -> None: ...
    def DeleteColumns(self, col: int, cols: int) -> None: ...
    def DeleteContent(self, nRow: int, nCol: int) -> None: ...
    def DeleteRows(self, row: int, Rows: int) -> None: ...
    def EnableMergeAll(self, nRow: int, nCol: int, bEnable: bool) -> None: ...
    def FormatValue(self, row: int, col: int, nOption: AcFormatOption) -> str: ...
    def GenerateLayout(self) -> None: ...
    def GetAlignment(self, rowType: AcRowType) -> AcCellAlignment: ...
    def GetAttachmentPoint(self, row: int, col: int) -> AcAttachmentPoint: ...
    def GetAutoScale(self, row: int, col: int) -> bool: ...
    def GetAutoScale2(self, nRow: int, nCol: int, nContent: int) -> bool: ...
    def GetBackgroundColor(self, rowType: AcRowType) -> AcadAcCmColor: ...
    def GetBackgroundColorNone(self, rowType: AcRowType) -> bool: ...
    def GetBlockAttributeValue(self, row: int, col: int, attdefId: int) -> str: ...
    def GetBlockAttributeValue2(self, nRow: int, nCol: int, nContent: int, blkId: int) -> str: ...
    def GetBlockRotation(self, row: int, col: int) -> float: ...
    def GetBlockScale(self, row: int, col: int) -> float: ...
    def GetBlockTableRecordId(self, row: int, col: int) -> int: ...
    def GetBlockTableRecordId2(self, nRow: int, nCol: int, nContent: int) -> int: ...
    def GetBreakHeight(self, nIndex: int) -> float: ...
    def GetCellAlignment(self, row: int, col: int) -> AcCellAlignment: ...
    def GetCellBackgroundColor(self, row: int, col: int) -> AcadAcCmColor: ...
    def GetCellBackgroundColorNone(self, row: int, col: int) -> bool: ...
    def GetCellContentColor(self, row: int, col: int) -> AcadAcCmColor: ...
    def GetCellDataType(self, row: int, col: int, pDataType: AcValueDataType, pUnitType: AcValueUnitType) -> None: ...
    def GetCellExtents(self, row: int, col: int, bOuterCell: bool) -> None: ...
    def GetCellFormat(self, row: int, col: int) -> str: ...
    def GetCellGridColor(self, row: int, col: int, edge: AcCellEdgeMask) -> AcadAcCmColor: ...
    def GetCellGridLineWeight(self, row: int, col: int, edge: AcCellEdgeMask) -> AcLineWeight: ...
    def GetCellGridVisibility(self, row: int, col: int, edge: AcCellEdgeMask) -> bool: ...
    def GetCellState(self, nRow: int, nCol: int) -> AcCellState: ...
    def GetCellStyle(self, nRow: int, nCol: int) -> str: ...
    def GetCellStyleOverrides(self, row: int, col: int) -> str: ...
    def GetCellTextHeight(self, row: int, col: int) -> float: ...
    def GetCellTextStyle(self, row: int, col: int) -> str: ...
    def GetCellType(self, row: int, col: int) -> AcCellType: ...
    def GetCellValue(self, row: int, col: int) -> Variant: ...
    def GetColumnName(self, nIndex: int) -> str: ...
    def GetColumnWidth(self, col: int) -> float: ...
    def GetContentColor(self, rowType: AcRowType) -> AcadAcCmColor: ...
    def GetCellContentColor2(self, nRow: int, nCol: int, nContent: int) -> AcadAcCmColor: ...
    def GetContentLayout(self, nRow: int, nCol: int) -> AcCellContentLayout: ...
    def GetContentType(self, nRow: int, nCol: int) -> AcCellContentType: ...
    def GetCustomData(self, nRow: int, nCol: int, szKey: str) -> Variant: ...
    def GetDataFormat(self, nRow: int, nCol: int, nContent: int) -> str: ...
    def GetDataType(self, rowType: AcRowType) -> tuple[AcValueDataType, AcValueUnitType]: ...
    def GetDataType2(self, nRow: int, nCol: int, nContent: int) -> tuple[AcValueDataType, AcValueUnitType]: ...
    def GetFieldId(self, row: int, col: int) -> int: ...
    def GetFieldId2(self, nRow: int, nCol: int, nContent: int) -> int: ...
    def GetFormat(self, rowType: AcRowType) -> str: ...
    def GetFormula(self, nRow: int, nCol: int, nContent: int) -> str: ...
    def GetGridColor(self, gridLineType: AcGridLineType, rowType: AcRowType) -> AcadAcCmColor: ...
    def GetGridColor2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> AcadAcCmColor: ...
    def GetGridDoubleLineSpacing(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> float: ...
    def GetGridLineStyle(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> AcGridLineStyle: ...
    def GetGridLinetype(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> int: ...
    def GetGridLineWeight(self, gridLineType: AcGridLineType, rowType: AcRowType) -> AcLineWeight: ...
    def GetGridLineWeight2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> AcLineWeight: ...
    def GetGridVisibility(self, gridLineType: AcGridLineType, rowType: AcRowType) -> bool: ...
    def GetGridVisibility2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> bool: ...
    def GetHasFormula(self, nRow: int, nCol: int, nContent: int) -> bool: ...
    def GetMargin(self, nRow: int, nCol: int, nMargin: AcCellMargin) -> float: ...
    def GetMinimumColumnWidth(self, col: int) -> float: ...
    def GetMinimumRowHeight(self, row: int) -> float: ...
    def GetOverride(self, nRow: int, nCol: int, nContent: int) -> AcCellProperty: ...
    def GetRotation(self, nRow: int, nCol: int, nContent: int) -> float: ...
    def GetRowHeight(self, row: int) -> float: ...
    def GetRowType(self, row: int) -> AcRowType: ...
    def GetScale(self, nRow: int, nCol: int, nContent: int) -> float: ...
    def GetSubSelection(self) -> tuple: ...
    def GetText(self, row: int, col: int) -> str: ...
    def GetTextHeight(self, rowType: AcRowType) -> float: ...
    def GetTextHeight2(self, nRow: int, nCol: int, nContent: int) -> float: ...
    def GetTextRotation(self, row: int, col: int) -> AcRotationAngle: ...
    def GetTextString(self, nRow: int, nCol: int, nContent: int) -> str: ...
    def GetTextStyle(self, rowTypes: AcRowType) -> str: ...
    def GetTextStyle2(self, nRow: int, nCol: int, nContent: int) -> str: ...
    def GetValue(self, nRow: int, nCol: int, nContent: int) -> Variant: ...
    def HitTest(self, wpt: PyGePoint3d, wviewVec: PyGeVector3d) -> vIntegerArray: ...
    def InsertColumns(self, col: int, Width: float, cols: int) -> None: ...
    def InsertColumnsAndInherit(self, col: int, nInheritFrom: int, nNumCols: int) -> None: ...
    def InsertRows(self, row: int, Height: float, Rows: int) -> None: ...
    def InsertRowsAndInherit(self, nIndex: int, nInheritFrom: int, nNumRows: int) -> None: ...
    def IsContentEditable(self, nRow: int, nCol: int) -> bool: ...
    def IsEmpty(self, nRow: int, nCol: int) -> bool: ...
    def IsFormatEditable(self, nRow: int, nCol: int) -> bool: ...
    def IsMergeAllEnabled(self, nRow: int, nCol: int) -> bool: ...
    def IsMergedCell(self, row: int, col: int, minRow: int, maxRow: int, minCol: int, maxCol: int) -> bool: ...
    def MergeCells(self, minRow: int, maxRow: int, minCol: int, maxCol: int) -> None: ...
    def MoveContent(self, nRow: int, nCol: int, nFromIndex: int, nToIndex: int) -> None: ...
    def RecomputeTableBlock(self, bForceUpdate: bool) -> None: ...
    def RemoveAllOverrides(self, nRow: int, nCol: int) -> None: ...
    def ReselectSubRegion(self) -> None: ...
    def ResetCellValue(self, row: int, col: int) -> None: ...
    def Select(self, wpt: PyGePoint3d, wvwVec: PyGeVector3d, wvwxvec: PyGeVector3d, allowOutside: bool) -> tuple[float, float, int, int]: ...
    def SelectSubRegion(self, wpt1: PyGePoint3d, wpt2: PyGePoint3d, wvwVec: PyGeVector3d, wvwxVec: PyGeVector3d, seltype: AcSelectType, bIncludeCurrentSelection: bool) -> tuple[int, int, int, int]: ...
    def SetAlignment(self, rowTypes: AcRowType, cellAlignment: AcCellAlignment) -> None: ...
    def SetAutoScale(self, row: int, col: int, bValue: bool) -> None: ...
    def SetAutoScale2(self, nRow: int, nCol: int, nContent: int, bAutoFit: bool) -> None: ...
    def SetBackgroundColor(self, rowTypes: AcRowType, pColor: AcadAcCmColor) -> None: ...
    def SetBackgroundColorNone(self, rowTypes: AcRowType, bValue: bool) -> None: ...
    def SetBlockAttributeValue(self, row: int, col: int, attdefId: int, StringValue: str) -> None: ...
    def SetBlockAttributeValue2(self, nRow: int, nCol: int, nContent: int, blkId: int, value: str) -> None: ...
    def SetBlockRotation(self, row: int, col: int, blkRotation: float) -> None: ...
    def SetBlockScale(self, row: int, col: int, blkScale: float) -> None: ...
    def SetBlockTableRecordId(self, row: int, col: int, blkId: int, bAutoFit: bool) -> None: ...
    def SetBlockTableRecordId2(self, nRow: int, nCol: int, nContent: int, blkId: int, autoFit: bool) -> None: ...
    def SetBreakHeight(self, nIndex: int, dHeight: float) -> None: ...
    def SetCellAlignment(self, row: int, col: int, cellAlignment: AcCellAlignment) -> None: ...
    def SetCellBackgroundColor(self, row: int, col: int, pColor: AcadAcCmColor) -> None: ...
    def SetCellBackgroundColorNone(self, row: int, col: int, bValue: bool) -> None: ...
    def SetCellContentColor(self, row: int, col: int, pColor: AcadAcCmColor) -> None: ...
    def SetCellDataType(self, row: int, col: int, dataType: AcValueDataType, unitType: AcValueUnitType) -> None: ...
    def SetCellFormat(self, row: int, col: int, pFormat: str) -> None: ...
    def SetCellGridColor(self, row: int, col: int, edges: AcCellEdgeMask, pColor: AcadAcCmColor) -> None: ...
    def SetCellGridLineWeight(self, row: int, col: int, edges: AcCellEdgeMask, Lineweight: AcLineWeight) -> None: ...
    def SetCellGridVisibility(self, row: int, col: int, edges: AcCellEdgeMask, bValue: bool) -> None: ...
    def SetCellState(self, nRow: int, nCol: int, nLock: AcCellState) -> None: ...
    def SetCellStyle(self, nRow: int, nCol: int, szCellStyle: str) -> None: ...
    def SetCellTextHeight(self, row: int, col: int, TextHeight: float) -> None: ...
    def SetCellTextStyle(self, row: int, col: int, bstrName: str) -> None: ...
    def SetCellType(self, row: int, col: int, CellType: AcCellType) -> None: ...
    def SetCellValue(self, row: int, col: int) -> Variant: ...
    def SetCellValueFromText(self, row: int, col: int, val: str, nOption: AcParseOption) -> None: ...
    def SetColumnName(self, nIndex: int, name: str) -> None: ...
    def SetColumnWidth(self, col: int, Width: float) -> None: ...
    def SetContentColor(self, rowTypes: AcRowType, pColor: AcadAcCmColor) -> None: ...
    def SetContentColor2(self, nRow: int, nCol: int, nContent: int, pColor: AcadAcCmColor) -> None: ...
    def SetContentLayout(self, nRow: int, nCol: int, nLayout: AcCellContentLayout) -> None: ...
    def SetCustomData(self, nRow: int, nCol: int, szKey: str, data: Variant) -> None: ...
    def SetDataFormat(self, nRow: int, nCol: int, nContent: int, szFormat: str) -> None: ...
    def SetDataType(self, rowTypes: AcRowType, nDataType: AcValueDataType, nUnitType: AcValueUnitType) -> None: ...
    def SetDataType2(self, nRow: int, nCol: int, nContent: int, dataType: AcValueDataType, unitType: AcValueUnitType) -> None: ...
    def SetFieldId(self, row: int, col: int, fieldId: int) -> None: ...
    def SetFieldId2(self, nRow: int, nCol: int, nContent: int, acDbObjectId: int, nflag: AcCellOption) -> None: ...
    def SetFormat(self, rowTypes: AcRowType, pFormat: str) -> None: ...
    def SetFormula(self, nRow: int, nCol: int, nContent: int, pszFormula: str) -> None: ...
    def SetGridColor(self, gridLineTypes: AcGridLineType, rowTypes: AcRowType, pColor: AcadAcCmColor) -> None: ...
    def SetGridColor2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, pColor: AcadAcCmColor) -> None: ...
    def SetGridDoubleLineSpacing(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, fSpacing: float) -> None: ...
    def SetGridLineStyle(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, nLineStyle: AcGridLineStyle) -> None: ...
    def SetGridLinetype(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, idLinetype: int) -> None: ...
    def SetGridLineWeight(self, gridLineTypes: AcGridLineType, rowTypes: AcRowType, Lineweight: AcLineWeight) -> None: ...
    def SetGridLineWeight2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, lineWeight: AcLineWeight) -> None: ...
    def SetGridVisibility(self, gridLineTypes: AcGridLineType, rowTypes: AcRowType, bValue: bool) -> None: ...
    def SetGridVisibility2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, bVisible: bool) -> None: ...
    def SetMargin(self, nRow: int, nCol: int, nMargins: AcCellMargin, fMargin: float) -> None: ...
    def SetOverride(self, nRow: int, nCol: int, nContent: int, nProp: AcCellProperty) -> None: ...
    def SetRotation(self, nRow: int, nCol: int, nContent: int, pValue: float) -> None: ...
    def SetRowHeight(self, row: int, Height: float) -> None: ...
    def SetScale(self, nRow: int, nCol: int, nContent: int, scale: float) -> None: ...
    def SetSubSelection(self, rowMin: int, rowMax: int, colMin: int, colMax: int) -> None: ...
    def SetText(self, row: int, col: int, pStr: str) -> None: ...
    def SetTextHeight(self, rowTypes: AcRowType, TextHeight: float) -> None: ...
    def SetTextHeight2(self, nRow: int, nCol: int, nContent: int, height: float) -> None: ...
    def SetTextRotation(self, row: int, col: int, TextRotation: AcRotationAngle) -> None: ...
    def SetTextString(self, nRow: int, nCol: int, nContent: int, text: str) -> None: ...
    def SetTextStyle(self, rowTypes: AcRowType, bstrName: str) -> None: ...
    def SetTextStyle2(self, nRow: int, nCol: int, nContent: int, StringStyleName: str) -> None: ...
    def SetToolTip(self, nRow: int, nCol: int, tip: str) -> None: ...
    def SetValue(self, nRow: int, nCol: int, nContent: int, acValue: Variant) -> None: ...
    def SetValueFromText(self, nRow: int, nCol: int, nContent: int, szText: str, nOption: AcParseOption) -> None: ...
    def UnmergeCells(self, minRow: int, maxRow: int, minCol: int, maxCol: int) -> None: ...
