from ..Base import *
from ..Proxy import *

class AcadSummaryInfo(AppObject):
    def __init__(self, obj) -> None: ...
    Author: str
    Comments: str
    HyperlinkBase: str
    Keywords: str
    LastSavedBy: str
    RevisionNumber: str
    Subject: str
    Title: str
    def AddCustomInfo(self, key: str, Value: str) -> None: ...
    def GetCustomByIndex(self, Index: int) -> str: ...
    def GetCustomByKey(self, pKey: str) -> vStringArray: ...
    def NumCustomInfo(self) -> int: ...
    def RemoveCustomByIndex(self, Index: int) -> None: ...
    def RemoveCustomByKey(self, key: str) -> None: ...
    def SetCustomByIndex(self, Index: int, key: str, Value: str) -> None: ...
    def SetCustomByKey(self, key: str, Value: str) -> None: ...
