from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property

class AcadRegisteredApplication(AcadObject):
    def __init__(self, obj) -> None: ...
    Name: str
