from ..Base import *
from ..Proxy import *
from ..AcadEntity import AcadEntity as AcadEntity

class AcadSpline(AcadEntity):
    def __init__(self, obj) -> None: ...
    Area: float
    Closed: bool
    Closed2: bool
    ControlPoints: PyGePoint3dArray
    Degree: int
    Degree2: int
    EndTangent: PyGeVector3d
    FitPoints: PyGePoint3dArray
    FitTolerance: float
    IsPeriodic: bool
    IsPlanar: bool
    IsRational: bool
    KnotParameterization: AcSplineKnotParameterizationType
    Knots: PyGeVector3d
    NumberOfControlPoints: int
    NumberOfFitPoints: int
    SplineFrame: AcSplineFrameType
    SplineMethod: AcSplineMethodType
    StartTangent: PyGeVector3d
    Weights: PyGeVector3d
    def AddFitPoint(self, Index: int, FitPoint: PyGePoint3d) -> None: ...
    def Copy(self) -> AcadSpline: ...
    def DeleteFitPoint(self, Index: int) -> None: ...
    def ElevateOrder(self, Order: int) -> None: ...
    def GetControlPoint(self, Index: int) -> PyGePoint3d: ...
    def GetFitPoint(self, Index: int) -> PyGePoint3d: ...
    def GetWeight(self, Index: int) -> int: ...
    def Offset(self, Distance: float) -> AcadSpline: ...
    def PurgeFitData(self) -> None: ...
    def Reverse(self) -> None: ...
    def SetControlPoint(self, Index: int, Value: PyGePoint3d) -> None: ...
    def SetFitPoint(self, Index: int, Value: PyGePoint3d) -> None: ...
    def SetWeight(self, Index: int, Weight: float) -> None: ...
