from ..Base import *
from ..Proxy import *
from ..AcadObject import *

class AcadTableStyle(AcadObject):
    def __init__(self, obj) -> None: ...
    BitFlags: int
    Description: str
    FlowDirection: AcTableDirection
    HeaderSuppressed: bool
    HorzCellMargin: float
    Name: str
    NumCellStyles: int
    TemplateId: int
    TitleSuppressed: bool
    VertCellMargin: float
    def CreateCellStyle(self, StringCellStyle: str) -> None: ...
    def CreateCellStyleFromStyle(self, StringCellStyle: str, StringSourceCellStyle: str) -> None: ...
    def DeleteCellStyle(self, StringCellStyle: str) -> None: ...
    def EnableMergeAll(self, nRow: int, nCol: int, bEnable: bool) -> None: ...
    def GetAlignment(self, rowType: AcRowType) -> AcCellAlignment: ...
    def GetAlignment2(self, bstrCellStyle: str) -> AcCellAlignment: ...
    def GetBackgroundColor(self, rowType: AcRowType) -> AcadAcCmColor: ...
    def GetBackgroundColor2(self, bstrCellStyle: str) -> AcadAcCmColor: ...
    def GetBackgroundColorNone(self, rowType: AcRowType) -> bool: ...
    def GetCellClass(self, StringCellStyle: str) -> int: ...
    def GetCellStyles(self) -> Variant: ...
    def GetColor(self, rowType: AcRowType) -> AcadAcCmColor: ...
    def GetColor2(self, bstrCellStyle: str) -> AcadAcCmColor: ...
    def GetDataType(self, rowType: AcRowType) -> tuple: ...
    def GetDataType2(self, nRow: int, nCol: int, nContent: int) -> tuple: ...
    def GetFormat(self, rowType: AcRowType) -> str: ...
    def GetFormat2(self, StringCellStyle: str) -> str: ...
    def GetGridColor(self, gridLineType: AcGridLineType, rowType: AcRowType) -> AcadAcCmColor: ...
    def GetGridColor2(self, bstrCellStyle: str, gridLineType: AcGridLineType) -> AcadAcCmColor: ...
    def GetGridLineWeight(self, gridLineType: AcGridLineType, rowType: AcRowType) -> AcLineWeight: ...
    def GetGridLineWeight2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> AcLineWeight: ...
    def GetGridVisibility(self, gridLineType: AcGridLineType, rowType: AcRowType) -> bool: ...
    def GetGridVisibility2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType) -> bool: ...
    def GetIsCellStyleInUse(self, pszCellStyle: str) -> bool: ...
    def GetIsMergeAllEnabled(self, StringCellStyle: str) -> bool: ...
    def GetRotation(self, StringCellStyle: str) -> float: ...
    def GetTextHeight(self, rowType: AcRowType) -> float: ...
    def GetTextHeight2(self, StringCellStyle: str) -> float: ...
    def GetTextStyle(self, rowType: AcRowType) -> str: ...
    def GetTextStyleId(self, bstrCellStyle: str) -> float: ...
    def GetUniqueCellStyleName(self, pszBaseName: str) -> str: ...
    def RenameCellStyle(self, StringOldName: str, StringNewName: str) -> None: ...
    def SetAlignment(self, rowTypes: AcRowType, cellAlignment: AcCellAlignment) -> None: ...
    def SetAlignment2(self, bstrCellStyle: str, cellAlignment: AcCellAlignment) -> None: ...
    def SetBackgroundColor(self, rowTypes: AcRowType, pColor: AcadAcCmColor) -> None: ...
    def SetBackgroundColor2(self, bstrCellStyle: str, color: AcadAcCmColor) -> None: ...
    def SetBackgroundColorNone(self, rowTypes: AcRowType, bValue: bool) -> None: ...
    def SetCellClass(self, StringCellStyle: str, cellClass: int) -> None: ...
    def SetColor(self, rowTypes: AcRowType, pColor: AcadAcCmColor) -> None: ...
    def SetColor2(self, bstrCellStyle: str, color: AcadAcCmColor) -> None: ...
    def SetDataType(self, rowTypes: AcRowType, nDataType: AcValueDataType, nUnitType: AcValueUnitType) -> None: ...
    def SetDataType2(self, nRow: int, nCol: int, nContent: int, dataType: AcValueDataType, unitType: AcValueUnitType) -> None: ...
    def SetFormat(self, rowTypes: AcRowType, pFormat: str) -> None: ...
    def SetFormat2(self, bstrCellStyle: str, bstrFormat: str) -> None: ...
    def SetGridColor(self, gridLineTypes: AcGridLineType, rowTypes: AcRowType, pColor: AcadAcCmColor) -> None: ...
    def SetGridColor2(self, nRow: int, nCol: int, nGridLineType: AcGridLineType, pColor: AcadAcCmColor) -> None: ...
    def SetGridLineWeight(self, gridLineTypes: AcGridLineType, rowTypes: AcRowType, Lineweight: AcLineWeight) -> None: ...
    def SetGridLineWeight2(self, bstrCellStyle: str, gridLineType: AcGridLineType, Lineweight: AcLineWeight) -> None: ...
    def SetGridVisibility(self, gridLineTypes: AcGridLineType, rowTypes: AcRowType, bVisible: bool) -> None: ...
    def SetGridVisibility2(self, bstrCellStyle: str, gridLineType: AcGridLineType, bValue: bool) -> None: ...
    def SetRotation(self, bstrCellStyle: str, Rotation: float) -> None: ...
    def SetTemplateId(self, val: int, option: AcMergeCellStyleOption) -> None: ...
    def SetTextHeight(self, rowTypes: AcRowType, TextHeight: float) -> None: ...
    def SetTextHeight2(self, bstrCellStyle: str, Height: float) -> None: ...
    def SetTextStyle(self, rowTypes: AcRowType, bstrName: str) -> None: ...
    def SetTextStyleId(self, bstrCellStyle: str, val: int) -> None: ...
