from simpleautocad import *
from colorama import Back as Back, Style as Style
from typing import Generator

OFFSET_DIR: PyGeVector3d
OFFSET_COUNT: int
OFFSET_DIST_X: int
OFFSET_DIST_Y: int
OFFSET_DIST_Z: int

def init_point(): ...
def acad_app() -> Generator[AutoCAD, None, None]: ...
def acad_active_document(acad_app: AutoCAD) -> Generator[AcadDocument, None, None]: ...
def acad_model_space(acad_active_document: AcadDocument) -> Generator[AcadModelSpace, None, None]: ...
def object_AcadCircle(acad_model_space: AcadModelSpace) -> Generator[AcadCircle, None, None]: ...
def object_Acad3DFace(acad_model_space: AcadModelSpace) -> Generator[Acad3DFace, None, None]: ...
def object_AcadPolygonMesh(acad_model_space: AcadModelSpace) -> Generator[AcadPolygonMesh, None, None]: ...
def object_Acad3DPolyline(acad_model_space: AcadModelSpace) -> Generator[Acad3DPolyline, None, None]: ...
def object_AddArc(acad_model_space: AcadModelSpace) -> Generator[AcadArc, None, None]: ...
def object_AcadAttribute(acad_model_space: AcadModelSpace) -> Generator[AcadAttribute, None, None]: ...
def object_AddMInsertBlock(acad_model_space: AcadModelSpace) -> Generator[AcadBlock, None, None]: ...
