from ..Base import *
from ..Proxy import *
from ..AcadObject import *
from .AcadLayout import *

class AcadLayouts(IAcadObjectCollection):
    def __init__(self, obj) -> None: ...
    def Add(self, InsertionPoint: PyGePoint3d, Name: str) -> AcadLayout: ...
    def Item(self, Index: int) -> AcadLayout: ...
    def __iter__(self): ...
