from ..Base import *
from ..AcadObject import *
from ..Proxy import AccessMode as AccessMode, proxy_property as proxy_property

class AcadPlotConfiguration(AcadObject):
    def __init__(self, obj) -> None: ...
    CanonicalMediaName: str
    CenterPlot: bool
    ConfigName: str
    ModelType: bool
    Name: str
    PaperUnits: AcPlotPaperUnits
    PlotHidden: bool
    PlotOrigin: PyGePoint2d
    PlotRotation: AcPlotRotation
    PlotType: AcPlotType
    PlotViewportBorders: bool
    PlotViewportsFirst: bool
    PlotWithLineweights: bool
    PlotWithPlotStyles: bool
    ScaleLineweights: bool
    ShowPlotStyles: bool
    StandardScale: AcPlotScale
    StyleSheet: str
    UseStandardScale: bool
    ViewToPlot: str
    def CopyFrom(self, SourceObject: AcadPlotConfiguration) -> None: ...
    def GetCanonicalMediaNames(self) -> tuple[str]: ...
    def GetCustomScale(self) -> vDoubleArray: ...
    def GetLocaleMediaName(self, Name: str) -> str: ...
    def GetPaperMargins(self) -> vDoubleArray: ...
    def GetPaperSize(self) -> tuple: ...
    def GetPlotDeviceNames(self) -> tuple[str]: ...
    def GetPlotStyleTableNames(self) -> tuple[str]: ...
    def GetWindowToPlot(self) -> PyGePoint2dArray: ...
    def RefreshPlotDeviceInfo(self) -> None: ...
    def SetCustomScale(self, Numerator: float, Denominator: float) -> None: ...
    def SetWindowToPlot(self, LowerLeft: PyGePoint2d, UpperRight: PyGePoint2d) -> None: ...
