from .VarType import *
from .Ac import AdeskDxfCode as AdeskDxfCode
from enum import IntEnum

class DxfGroupXDCode(IntEnum):
    kDxfXdAsciiString = ...
    kDxfRegAppName = ...
    kDxfXdControlString = ...
    kDxfXdLayerName = ...
    kDxfXdBinaryChunk = ...
    kDxfXdHandle = ...
    kDxfXdXCoord = ...
    kDxfXdWorldXCoord = ...
    kDxfXdWorldXDisp = ...
    kDxfXdWorldXDir = ...
    kDxfXdReal = ...
    kDxfXdDist = ...
    kDxfXdScale = ...
    kDxfXdInteger16 = ...
    kDxfXdInteger32 = ...

class XDataManager:
    def __init__(self, regAppName: str = '') -> None: ...
    @property
    def RegAppName(self) -> str: ...
    @RegAppName.setter
    def RegAppName(self, value: str) -> str: ...
    @property
    def xDataType(self) -> vShortArray: ...
    @property
    def xDataValue(self) -> vVariantArray: ...
    def add_data(self, group_code: DxfGroupXDCode | list[DxfGroupXDCode] | tuple[DxfGroupXDCode], value: int | str | float | list[int | str | float] | tuple[int | str | float]): ...
    def __getitem__(self, key): ...
    def __setitem__(self, key, value) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self): ...
